//
// C++ Interface: CGuitxtEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CGUITXTEDITDLG_H
#define CGUITXTEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_guitxtdlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CGUITextEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CGUITextEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CGUITextEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditColor();
 
private slots:
 
protected:
    Ui::GUITextEditDlg ui;    
    FolderListItem *point;
    QColor mycolor;
    
private:
    QWidget *myParent;
};
#endif
